@@ -1,7 +1,7 @@
 use swc_ecma_parser::Syntax;
 use swc_ecma_visit::Fold;
 
-use super::*;
+use super::{InnerConfig, *};
 use crate::hygiene::Config;
 
 // struct TsHygiene {
@@ -62,23 +62,38 @@ fn test_mark_for() {
         let mark3 = Mark::fresh(mark2);
         let mark4 = Mark::fresh(mark3);
 
-        let folder1 = Resolver::new(Scope::new(ScopeKind::Block, mark1, None), true);
+        let folder1 = Resolver::new(
+            Scope::new(ScopeKind::Block, mark1, None),
+            InnerConfig {
+                handle_types: true,
+                unresolved_mark: Mark::fresh(Mark::root()),
+            },
+        );
         let mut folder2 = Resolver::new(
             Scope::new(ScopeKind::Block, mark2, Some(&folder1.current)),
-            true,
+            InnerConfig {
+                handle_types: true,
+                unresolved_mark: Mark::fresh(Mark::root()),
+            },
         );
         folder2.current.declared_symbols.insert("foo".into());
 
         let mut folder3 = Resolver::new(
             Scope::new(ScopeKind::Block, mark3, Some(&folder2.current)),
-            true,
+            InnerConfig {
+                handle_types: true,
+                unresolved_mark: Mark::fresh(Mark::root()),
+            },
         );
         folder3.current.declared_symbols.insert("bar".into());
         assert_eq!(folder3.mark_for_ref(&"bar".into()), Some(mark3));
 
         let mut folder4 = Resolver::new(
             Scope::new(ScopeKind::Block, mark4, Some(&folder3.current)),
-            true,
+            InnerConfig {
+                handle_types: true,
+                unresolved_mark: Mark::fresh(Mark::root()),
+            },
         );
         folder4.current.declared_symbols.insert("foo".into());
 
@@ -93,7 +108,7 @@ fn test_mark_for() {
 fn issue_1279_1() {
     run_test_with_config(
         Default::default(),
-        resolver,
+        || resolver(Mark::new(), Mark::new(), false),
         "class Foo {
             static f = 1;
             static g = Foo.f;
@@ -114,7 +129,7 @@ fn issue_1279_1() {
 fn issue_1279_2() {
     run_test_with_config(
         Default::default(),
-        resolver,
+        || resolver(Mark::new(), Mark::new(), false),
         "class Foo {
             static f = 1;
             static g = Foo.f;
@@ -147,7 +162,7 @@ fn issue_1279_2() {
 fn issue_2516() {
     run_test_with_config(
         Default::default(),
-        resolver,
+        || resolver(Mark::new(), Mark::new(), false),
         "class A {
             static A = class {}
           }",
